/*
  Example code for using LPFILTER.C
  Built on PIC v6 with PIC18

  PIC18F4525 @ 40MHz
  Adjust to fit your hardware.
*/

#include "lpfilter.h"

int adc_filtered;
int adc_now;
float volts_now;
float volts_filtered;

/*
  PrintHandler used in conjunctio with PRINTOUT in
  MicroC Pro library to send SPRINTF type strings
  to UART, one byte at a time. Can include all
  escapes, formatting, etc. in ANSI C SPRINTF sends
  data to screen, PRINTOUT sends wherever we want,
  in this case the UART.

  PrintOut(PrintHandler, "number &u4 is a 4 digit integer", 1234);
*/
void PrintHandler(char c)
{
     UART1_Write(c);
}

/*
  If you set a breakpoint at the NOTE below, you can watch the
  filtered value come up and become stable. This will give you
  an idea of how many samples it takes to stabilize, depending on
  the K value you compiled with.
*/
void main() 
{
//    ADCON1 |= 0x0F;      // Configure AN pins as digital
    CMCON  |= 7;         // Disable comparators
    INTCON2.B7 = 0;      // enable pullups on port b
    UART1_Init(57600);  // Initialize
    init_lpfilter();
    ADC_Init();          // init ADC
    UART1_Write_Text("LPFILTER DEMO\r\n");
    Delay_ms(1000);


    while(1)
    {
         adc_now = ADC_Read(3);              // read adc counts
         add_filter_value(adc_now);          // add to LPFilter
         adc_filtered = get_filter_value();  // get filtered value counts
         asm nop;
         asm nop;
         // convert to volts
         volts_now = (float)adc_now * 0.0048828125;
         volts_filtered = (float)adc_filtered * 0.0048828125;
         asm nop;
         asm nop;
         // write values to UART
         PrintOut(PrintHandler, "VOLTS NOW:  %1.4f   VOLTS FILTERED:  %1.4f\r",volts_now,volts_filtered);
         asm nop;
         asm nop;
         Delay_ms(10);
    }
}